@@ -13,14 +13,16 @@ import tomli
 
 
 class BaseConfig(object):
-    """ Base configuration class
+    """Base configuration class
 
     This class holds and/or gathers all the APIs base settings...
 
     """
 
     APP_NAME = os.environ.get("APP_NAME", __name__)
-    APP_DESCRIPTION = os.environ.get("APP_DESCRIPTION", """Alliander Weather Provider API""")
+    APP_DESCRIPTION = os.environ.get(
+        "APP_DESCRIPTION", """Alliander Weather Provider API"""
+    )
     APP_MAINTAINER = os.environ.get("APP_MAINTAINER", "DNB/ST Innovatieteam")
     APP_MAINTAINER_EMAIL = os.environ.get(
         "APP_MAINTAINER_EMAIL", "weather.provider@alliander.com"
@@ -29,17 +31,17 @@ class BaseConfig(object):
 
     default_version = None
     try:
-        if Path('./pyproject.toml').exists():
-            pyproject_file = Path('./pyproject.toml')
-        elif Path('../pyproject.toml').exists():
-            pyproject_file = Path('../pyproject.toml')
-        with open(pyproject_file, mode='rb') as file:
-            default_version = tomli.load(file)['tool']['poetry']['version']
+        if Path("./pyproject.toml").exists():
+            pyproject_file = Path("./pyproject.toml")
+        elif Path("../pyproject.toml").exists():
+            pyproject_file = Path("../pyproject.toml")
+        with open(pyproject_file, mode="rb") as file:
+            default_version = tomli.load(file)["tool"]["poetry"]["version"]
     except Exception:
         default_version = importlib_metadata.version(__package__)
     finally:
         if not default_version:
-            default_version = 'Version Unidentified'
+            default_version = "Version Unidentified"
     APP_VERSION = os.environ.get("APP_VERSION", default_version)
 
     APP_V1_VERSION = os.environ.get("APP_V1_VERSION", f"{APP_VERSION} - v1 API (1.0.3)")
@@ -53,7 +55,9 @@ class BaseConfig(object):
     DEPLOYED = os.environ.get("DEPLOYED", False)
     DEBUG = os.environ.get("DEBUG", True)
 
-    REPO_FOLDER = os.environ.get("REPO_FOLDER", f"{tempfile.gettempdir()}/Weather_Repository")
+    REPO_FOLDER = os.environ.get(
+        "REPO_FOLDER", f"{tempfile.gettempdir()}/Weather_Repository"
+    )
 
 
 class LocalConfig(BaseConfig):
