@@ -13,7 +13,6 @@ class APIExpiredException(HTTPException):
     def __init__(self, detail: Any = None):
         self.detail = (
             detail
-            or "This API has passed it's expiry date and should be revalidated. "
-            "Please contact the API maintainer."
+            or "This API has passed it's expiry date and should be revalidated. " "Please contact the API maintainer."
         )
         self.status_code = 404
