@@ -10,15 +10,14 @@ from typing import List, Optional
 import numpy as np
 import xarray as xr
 
-from weather_provider_api.core.initializers.exception_handling import (
-    NOT_IMPLEMENTED_ERROR,
-)
 from weather_provider_api.routers.weather.api_models import OutputUnit
 from weather_provider_api.routers.weather.utils.geo_position import GeoPosition
 
 
 class WeatherModelBase(metaclass=ABCMeta):
-    """Base class for all Weather Models. All new models should use this base class!"""
+    """
+    Base class for all Weather Models. All new models should use this base class!
+    """
 
     def __init__(self):
         self.to_si = None
@@ -33,14 +32,15 @@ class WeatherModelBase(metaclass=ABCMeta):
         end: Optional[np.datetime64],
         weather_factors: List[str] = None,
     ) -> xr.Dataset:  # pragma: no cover
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR)
+        print("This method is abstract and should be overridden.")
 
     @abstractmethod
     def is_async(self):  # pragma: no cover
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR)
+        print("This method is abstract and should be overridden.")
 
     def convert_names_and_units(self, weather_data: xr.Dataset, unit: OutputUnit):
-        """Function to convert all names and units in a dataset according to the required translations set in the
+        """
+            Function to convert all names and units in a dataset according to the required translations set in the
             to_xxxx values for the model itself
         Args:
             weather_data:   A Xarray Dataset containing
@@ -70,9 +70,8 @@ class WeatherModelBase(metaclass=ABCMeta):
 
             new_data = weather_data[var_name]
             if "convert" in conversion_dict[var_name]:
-                dtype_value = new_data.dtype
                 converter: callable = conversion_dict[var_name]["convert"]
-                new_data = converter(weather_data[var_name]).astype(dtype_value)
+                new_data = converter(weather_data[var_name])
 
             weather_data = weather_data.drop_vars(var_name)
             weather_data[new_name] = new_data
@@ -91,7 +90,7 @@ class WeatherModelBase(metaclass=ABCMeta):
 
     @abstractmethod
     def _request_weather_factors(self, factors: Optional[List[str]]) -> List[str]:
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR)
+        print("This method is abstract and should be overridden.")
 
     @staticmethod
     def celsius_to_kelvin(x):  # pragma: no cover
@@ -122,6 +121,7 @@ class WeatherModelBase(metaclass=ABCMeta):
 
     @staticmethod
     def dutch_wind_direction_to_degrees(xs):
+
         wind_directions = [
             "NNO",
             "NO",
@@ -151,7 +151,8 @@ class WeatherModelBase(metaclass=ABCMeta):
 
     @staticmethod
     def knmi_visibility_class_to_meter_estimate(xs):
-        """Function to transform KNMI visibility class values to an estimate of meters visibility
+        """
+            Function to transform KNMI visibility class values to an estimate of meters visibility
         Args:
             xs:     The visibility class value to be interpreted
 
