@@ -4,15 +4,14 @@
 #  SPDX-FileCopyrightText: 2019-2023 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-"""This module houses the repository class for the Actuele Waarnemingen Register."""
-
+""" This module houses the repository class for the Actuele Waarnemingen Register. """
 from datetime import datetime
 from typing import List
 
+import structlog
 import xarray as xr
 from dateutil import tz
 from dateutil.relativedelta import relativedelta
-from loguru import logger
 
 from weather_provider_api.routers.weather.repository.repository import (
     WeatherRepositoryBase,
@@ -30,10 +29,11 @@ class ActueleWaarnemingenRegisterRepository(WeatherRepositoryBase):
     """ """
 
     def _delete_files_outside_of_scope(self):
-        logger.info(f"Deleting files outside of scope [{self.first_day_of_repo} - {self.last_day_of_repo}]")
         if self.filename.exists():
             current_data = xr.load_dataset(self.filename, engine="netcdf4")
-            current_data = current_data.sel(time=slice(self.first_day_of_repo, self.last_day_of_repo))
+            current_data = current_data.sel(
+                time=slice(self.first_day_of_repo, self.last_day_of_repo)
+            )
             current_data.to_netcdf(self.filename, format="NETCDF4")
 
     def _get_file_list_for_period(self, start: datetime, end: datetime):
@@ -43,6 +43,7 @@ class ActueleWaarnemingenRegisterRepository(WeatherRepositoryBase):
         # Pre-work
         super().__init__()
 
+        self.logger = structlog.get_logger(__name__)
         self.repository_name = "KNMI Actuele Waarnemingen - 48 uur register"
 
         # Repository settings
@@ -50,9 +51,12 @@ class ActueleWaarnemingenRegisterRepository(WeatherRepositoryBase):
         self.runtime_limit = 3 * 60  # Three minutes maximum runtime
         self.permanent_suffixes = []
         self.filename = self.repository_folder / f"{self.file_prefix}_register.nc"
-        self.file_identifier_length = 8
+        self.file_identifier_length = 0
 
-        logger.debug(f"Initialized the [{self.repository_name}] repository")
+        self.logger.debug(
+            f"Initialized the [{self.repository_name}] repository",
+            datetime=datetime.utcnow(),
+        )
 
     @property
     def repository_sub_folder(self):
@@ -103,7 +107,9 @@ class ActueleWaarnemingenRegisterRepository(WeatherRepositoryBase):
         # Update the file
         self._update_file_with_new_data(new_data_ds=raw_weather_ds, update_moment=time)
 
-    def _update_file_with_new_data(self, new_data_ds: xr.Dataset, update_moment: datetime):
+    def _update_file_with_new_data(
+        self, new_data_ds: xr.Dataset, update_moment: datetime
+    ):
         """This method updates any existing data file with new data or creates a new from scratch if needed, using the
          given dataset.
 
@@ -122,8 +128,8 @@ class ActueleWaarnemingenRegisterRepository(WeatherRepositoryBase):
         else:
             stored_data_ds = None
 
-        logger.info(
-            f"Storing data at [{update_moment.strftime('%m-%d-%Y %H:%M:%S')}] for "
+        self.logger.info(
+            f"Storing data for: {update_moment.strftime('%m-%d-%Y %H:%M:%S')} "
             f"[{new_data_ds.isel(STN=0, time=0)['time'].values}]"
         )
         if stored_data_ds is None:
@@ -135,7 +141,7 @@ class ActueleWaarnemingenRegisterRepository(WeatherRepositoryBase):
 
                 new_stored_data_ds.to_netcdf(self.filename, format="NETCDF4")
             except ValueError as value_error:
-                logger.error(f"Could not update file: {value_error}")
+                self.logger.warning(f"Could not update file: {value_error}")
 
     def get_24_hour_registry_for_station(self, station: int) -> xr.Dataset:
         """This method obtains the last 24 hours of data of Actuele Waarnemingen and returns it for single station.
@@ -150,7 +156,9 @@ class ActueleWaarnemingenRegisterRepository(WeatherRepositoryBase):
         stored_data_ds = xr.load_dataset(self.filename, engine="netcdf4")
         return stored_data_ds.sel(
             STN=station,
-            time=slice(self.first_day_of_repo + relativedelta(days=1), self.last_day_of_repo),
+            time=slice(
+                self.first_day_of_repo + relativedelta(days=1), self.last_day_of_repo
+            ),
         )
 
     def get_48_hour_registry_for_station(self, station: int) -> xr.Dataset:
