@@ -4,7 +4,9 @@
 #  SPDX-FileCopyrightText: 2019-2022 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-"""KNMI day models data fetcher."""
+"""
+    KNMI day models data fetcher.
+"""
 
 import copy
 import json
@@ -14,10 +16,9 @@ from typing import List, Optional
 import numpy as np
 import pandas as pd
 import requests
+import structlog
 import xarray as xr
 from dateutil.relativedelta import relativedelta
-from loguru import logger
-from pytz import UTC
 
 from weather_provider_api.routers.weather.base_models.model import WeatherModelBase
 from weather_provider_api.routers.weather.sources.knmi.stations import stations_history
@@ -32,7 +33,8 @@ from weather_provider_api.routers.weather.utils.pandas_helpers import coords_to_
 
 
 class DagGegevensModel(WeatherModelBase):
-    """A Weather Model that incorporates the:
+    """
+    A Weather Model that incorporates the:
         KNMI Daggegevens
     dataset into the Weather Provider API
     """
@@ -41,7 +43,7 @@ class DagGegevensModel(WeatherModelBase):
         super().__init__()
         self.id = "daggegevens"
         self.name = "KNMI daggegevens"
-        self.version = ""
+        self.version = None
         self.url = "https://daggegevens.knmi.nl/klimatologie/daggegevens"
         self.predictive = False
         self.time_step_size_minutes = 1440
@@ -174,7 +176,11 @@ class DagGegevensModel(WeatherModelBase):
             "ALL",
         ]
 
-        logger.debug(f"Weather model [{self.id}] initialized successfully")
+        self.logger = structlog.get_logger(__name__)
+        self.logger.debug(
+            f"Weather model [{self.id}] initialized successfully",
+            datetime=datetime.utcnow(),
+        )
 
     def get_weather(
         self,
@@ -184,25 +190,28 @@ class DagGegevensModel(WeatherModelBase):
         inseason=False,
         weather_factors: List[str] = None,
     ) -> xr.Dataset:
-        """The function that gathers and processes the requested Daggegevens weather data from the KNMI site
+        """
+            The function that gathers and processes the requested Daggegevens weather data from the KNMI site
             and returns it as a Xarray Dataset.
             (Though this model downloads from a specific download url, the question remains whether this source is also
             listed on the new KNMI Data Platform)
-
         Args:
             coords:             A list of GeoPositions containing the locations the data is requested for.
             begin:              A datetime containing the start of the period to request data for.
             end:                A datetime containing the end of the period to request data for.
             inseason:           A boolean representing the "inseason" parameter
             weather_factors:    A list of weather factors to request data for (in string format)
-
         Returns:
             An Xarray Dataset containing the weather data for the requested period, locations and factors.
         """
         # Test and account for invalid datetime timeframes or input
-        begin, end = validate_begin_and_end(begin, end, None, datetime.now(UTC) - relativedelta(days=1))
+        begin, end = validate_begin_and_end(
+            begin, end, None, datetime.utcnow() - relativedelta(days=1)
+        )
         # Get a list of the relevant STNs and choose the closest STN for each coordinate
-        station_id, stns, _ = find_closest_stn_list(stations_history, coords)
+        station_id, stns, coords_stn_ind = find_closest_stn_list(
+            stations_history, coords
+        )
 
         # Download the weather data for the relevant STNs
         raw_data = self._download_weather(
@@ -219,12 +228,11 @@ class DagGegevensModel(WeatherModelBase):
         # Prepare and format the weather data for output
         ds = self._prepare_weather_data(coords, station_id, raw_ds)
 
-        # The KNMI model isn't working properly yet, so we have to cut out any overflow time-wise
-        ds = ds.sel(time=slice(begin.astimezone(UTC).replace(tzinfo=None), end.astimezone(UTC).replace(tzinfo=None)))
-
+        # The KNMI model isn't working properly yet, so we have to cut out any overflow time-wise..
+        ds = ds.sel(time=slice(begin, end))
         return ds
 
-    def is_async(self) -> bool:  # pragma: no cover
+    def is_async(self):  # pragma: no cover
         return self.async_model
 
     def _download_weather(
@@ -235,19 +243,21 @@ class DagGegevensModel(WeatherModelBase):
         inseason=False,
         weather_factors: List[str] = None,
     ):
-        """A function that downloads the weather from the KNMI download location and returns it as a text
+        """
+            A function that downloads the weather from the KNMI download location and returns it as a text
         Args:
             stations:           A list containing the requested stations
             start:              A datetime containing the start of the period to request data for.
             end:                A datetime containing the end of the period to request data for.
             inseason:           A boolean representing the "inseason" parameter
             weather_factors:    A list of weather factors to request data for (in string format)
-
         Returns:
             A field containing the full response of the made download-request (text-based)
         """
         # fetch data
-        params = self._create_request_params(start, end, inseason, stations, weather_factors)
+        params = self._create_request_params(
+            start, end, inseason, stations, weather_factors
+        )
         r = requests.post(url=self.download_url, data=params)
 
         if r.status_code != 200:
@@ -260,15 +270,14 @@ class DagGegevensModel(WeatherModelBase):
         return r.text
 
     def _create_request_params(self, start, end, inseason, stations, weather_factors):
-        """A Function that transforms the request settings into parameters usable for the KMNI download request.
-
+        """
+            A Function that transforms the request settings into parameters usable for the KMNI download request.
         Args:
             start:              A datetime containing the start of the period to request data for.
             end:                A datetime containing the end of the period to request data for.
             inseason:           A boolean representing the "inseason" parameter
             stations:           A list containing the requested stations
             weather_factors:    A list of weather factors to request data for (in string format)
-
         Returns:
             A params field (string) containing the matching settings for a KNMI Daggegevens download request.
         """
@@ -307,9 +316,7 @@ class DagGegevensModel(WeatherModelBase):
         return dataframe_data.to_xarray()
 
     @staticmethod
-    def _prepare_weather_data(
-        coordinates: List[GeoPosition], station_id: list[np.int64], raw_ds: xr.Dataset
-    ) -> xr.Dataset:
+    def _prepare_weather_data(coordinates: List[GeoPosition], station_id, raw_ds):
         # A function that prepares the weather data for return by the API, by replacing the matching station with the
         # lat/lon location that was requested, and properly formatting the dimensions.
 
@@ -317,7 +324,10 @@ class DagGegevensModel(WeatherModelBase):
         ds = raw_ds.sel(station_code=station_id)
 
         # dict of data
-        data_dict = {var_name: (["coord", "time"], var.values) for var_name, var in ds.data_vars.items()}
+        data_dict = {
+            var_name: (["coord", "time"], var.values)
+            for var_name, var in ds.data_vars.items()
+        }
         timeline = pd.DatetimeIndex(ds.coords["date"].values)
 
         ds = xr.Dataset(
@@ -325,7 +335,6 @@ class DagGegevensModel(WeatherModelBase):
             coords={"time": timeline, "coord": coords_to_pd_index(coordinates)},
         )
         ds = ds.unstack("coord")
-
         return ds
 
     def _request_weather_factors(self, factors: Optional[List[str]]) -> List[str]:
