@@ -4,8 +4,8 @@
 #  SPDX-FileCopyrightText: 2019-2022 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-"""KNMI hour models data fetcher."""
-
+"""KNMI hour models data fetcher.
+"""
 import copy
 import json
 from datetime import datetime
@@ -14,31 +14,30 @@ from typing import List, Optional
 import numpy as np
 import pandas as pd
 import requests
+import structlog
 import xarray as xr
 from dateutil.relativedelta import relativedelta
-from loguru import logger
-from pytz import UTC
 
 from weather_provider_api.routers.weather.base_models.model import WeatherModelBase
 from weather_provider_api.routers.weather.sources.knmi.stations import stations_history
-from weather_provider_api.routers.weather.sources.knmi.utils import (
-    find_closest_stn_list,
-)
-from weather_provider_api.routers.weather.utils.date_helpers import (
-    validate_begin_and_end,
-)
+from weather_provider_api.routers.weather.sources.knmi.utils import find_closest_stn_list
+from weather_provider_api.routers.weather.utils.date_helpers import validate_begin_and_end
 from weather_provider_api.routers.weather.utils.geo_position import GeoPosition
 from weather_provider_api.routers.weather.utils.pandas_helpers import coords_to_pd_index
 
 
 class UurgegevensModel(WeatherModelBase):
-    """A Weather Model that incorporates the: KNMI Uurgegevens dataset into the Weather Provider API."""
+    """
+    A Weather Model that incorporates the:
+        KNMI Uurgegevens
+    dataset into the Weather Provider API
+    """
 
     def __init__(self):
         super().__init__()
         self.id = "uurgegevens"
         self.name = "KNMI uurgegevens"
-        self.version = ""
+        self.version = None
         self.url = "https://daggegevens.knmi.nl/klimatologie/uurgegevens"
         self.predictive = False
         self.time_step_size_minutes = 1440
@@ -134,34 +133,36 @@ class UurgegevensModel(WeatherModelBase):
             "ALL",
         ]
 
-        logger.debug(f"Weather model [{self.id}] initialized successfully")
+        self.logger = structlog.get_logger(__name__)
+        self.logger.debug(
+            f"Weather model [{self.id}] initialized successfully",
+            datetime=datetime.utcnow(),
+        )
 
     def get_weather(
         self,
         coords: List[GeoPosition],
         begin: datetime,
         end: datetime,
-        weather_factors: List[str] | None = None,
+        weather_factors: List[str] = None,
     ) -> xr.Dataset:
-        """The function that gathers and processes the requested Daggegevens weather data from the KNMI site
-        and returns it as a Xarray Dataset.
-
-        (Though this model downloads from a specific download url, the question remains whether this source is also
-        listed on the new KNMI Data Platform).
-
+        """
+            The function that gathers and processes the requested Daggegevens weather data from the KNMI site
+            and returns it as a Xarray Dataset.
+            (Though this model downloads from a specific download url, the question remains whether this source is also
+            listed on the new KNMI Data Platform)
         Args:
             coords:             A list of GeoPositions containing the locations the data is requested for.
             begin:              A datetime containing the start of the period to request data for.
             end:                A datetime containing the end of the period to request data for.
             weather_factors:    A list of weather factors to request data for (in string format)
-
         Returns:
             An Xarray Dataset containing the weather data for the requested period, locations and factors.
         """
         # Test and account for invalid datetime timeframes or input
         begin, end = validate_begin_and_end(begin, end, None, datetime.utcnow() - relativedelta(days=1))
         # Get a list of the relevant STNs and choose the closest STN for each coordinate
-        station_id, stns, _ = find_closest_stn_list(stations_history, coords)
+        station_id, stns, coords_stn_ind = find_closest_stn_list(stations_history, coords)
 
         # Download the weather data for the relevant STNs
         raw_data = self._download_weather(
@@ -177,8 +178,8 @@ class UurgegevensModel(WeatherModelBase):
         # Prepare and format the weather data for output
         ds = self._prepare_weather_data(coords, station_id, raw_ds)
 
-        # The KNMI model isn't working properly yet, so we have to cut out any overflow time-wise
-        ds = ds.sel(time=slice(begin.astimezone(UTC).replace(tzinfo=None), end.astimezone(UTC).replace(tzinfo=None)))
+        # The KNMI model isn't working properly yet, so we have to cut out any overflow time-wise..
+        ds = ds.sel(time=slice(begin, end))
         return ds
 
     def is_async(self):  # pragma: no cover
@@ -189,21 +190,21 @@ class UurgegevensModel(WeatherModelBase):
         stations: List[int],
         start: datetime,
         end: datetime,
-        weather_factors: List[str] | None = None,
+        weather_factors: List[str] = None,
     ):
-        """A function that downloads the weather from the KNMI download location and returns it as a text
+        """
+            A function that downloads the weather from the KNMI download location and returns it as a text
         Args:
             stations:           A list containing the requested stations
             start:              A datetime containing the start of the period to request data for.
             end:                A datetime containing the end of the period to request data for.
             weather_factors:    A list of weather factors to request data for (in string format)
-
         Returns:
             A field containing the full response of the made download-request (text-based)
         """
         # fetch data
         params = self._create_request_params(start, end, stations, weather_factors)
-        r = requests.post(url=self.download_url, data=params, timeout=60)
+        r = requests.post(url=self.download_url, data=params)
 
         if r.status_code != 200:
             raise requests.HTTPError(
@@ -219,21 +220,14 @@ class UurgegevensModel(WeatherModelBase):
             )
         return r.text
 
-    def _create_request_params(
-        self,
-        start: datetime,
-        end: datetime,
-        stations: list[int],
-        weather_factors: list[str],
-    ):
-        """A Function that transforms the request settings into parameters usable for the KMNI download request.
-
+    def _create_request_params(self, start, end, stations, weather_factors):
+        """
+            A Function that transforms the request settings into parameters usable for the KMNI download request.
         Args:
             start:              A datetime containing the start of the period to request data for.
             end:                A datetime containing the end of the period to request data for.
             stations:           A list containing the requested stations
             weather_factors:    A list of weather factors to request data for (in string format)
-
         Returns:
             A params field (string) containing the matching settings for a KNMI Daggegevens download request.
         """
@@ -274,18 +268,17 @@ class UurgegevensModel(WeatherModelBase):
 
         # Merge the hours with the date field and drop the timestamp and hour fields
         dataframe_data["date"] = dataframe_data["date"] + dataframe_data["timestamp"]
-        dataframe_data = dataframe_data.drop(["hour", "timestamp"], axis=1)
+        dataframe_data.drop(["hour", "timestamp"], axis=1, inplace=True)
 
         dataframe_data = dataframe_data.set_index(["station_code", "date"])
 
         return dataframe_data.to_xarray()
 
     @staticmethod
-    def _prepare_weather_data(coordinates: List[GeoPosition], station_id: list[np.int64], raw_ds: xr.Dataset):
-        """A function that prepares the weather data for return by the API, by replacing the matching station with the
-        lat/lon location that was requested, and properly formatting the dimensions.
+    def _prepare_weather_data(coordinates: List[GeoPosition], station_id, raw_ds):
+        # A function that prepares the weather data for return by the API, by replacing the matching station with the
+        # lat/lon location that was requested, and properly formatting the dimensions.
 
-        """
         # re-arrange stns
         ds = raw_ds.sel(station_code=station_id)
 
@@ -301,9 +294,7 @@ class UurgegevensModel(WeatherModelBase):
         return ds
 
     def _request_weather_factors(self, factors: Optional[List[str]]) -> List[str]:
-        """Implementation of the Base Weather Model function that returns a list of known weather factors for the
-        model.
-        """
+        # Implementation of the Base Weather Model function that returns a list of known weather factors for the model.
         if factors is None:
             return list(self.to_si.keys())
 
