@@ -4,7 +4,9 @@
 #  SPDX-FileCopyrightText: 2019-2022 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-"""The list of stations used in various KNMI datasets."""
+"""
+    The list of stations used in various KNMI datasets.
+"""
 
 from collections import namedtuple
 
