@@ -8,10 +8,10 @@ import os
 import site
 from pathlib import Path
 
-from loguru import logger
+import structlog
 
 
-async def remove_file(file_path):  # pragma: no cover
+async def remove_file(file_path, logger=structlog.get_logger(__name__)):  # pragma: no cover
     if file_path is not None:
         try:
             file_to_rm = Path(file_path).resolve()
@@ -25,6 +25,7 @@ async def remove_file(file_path):  # pragma: no cover
 
 
 def get_var_map_file_location(filename: str) -> Path:
+    logger = structlog.get_logger(__name__)
     var_map_folder = "var_maps"
 
     possible_main_folders = [
